/*
 * Copyright (C) 2013 Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.OnlineAccounts 0.1
import Friends 0.1

Rectangle {
    id: post
    width: parent.width
    height: parent.height

    FriendsDispatcher {
        id: friends
        onUploadComplete: {
             if (success) {
                 console.log ("SUCCESS");
                 post.visible = false;
             } else {
                 console.log ("FAILED: " + errorMessage);
             }
         }
         onSendComplete: {
             if (success) {
                 activitySpinner.visible = false;
                 post.visible = false;
                 console.log ("Send completed successfully");
             } else {
                 console.log ("Send failed: " + errorMessage);
             }
         }
    }


    Item {
        id: postHeader
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.topMargin: units.gu(1)
        anchors.leftMargin: units.gu(1)
        anchors.rightMargin: units.gu(1)

        height: childrenRect.height + units.gu(1)

        UbuntuShape {
            id: logo
            anchors.left: parent.left
            anchors.top: parent.top
            width: units.gu(5)
            height: units.gu(5)

            image: Image {
                fillMode: Image.PreserveAspectFit
                source: "images/header_image.png"
                sourceSize.height: logo.height
                sourceSize.width: logo.height
            }
        }

        Label {
            anchors.top: parent.top
            anchors.left: logo.right
            anchors.leftMargin: units.gu(1)
            anchors.rightMargin: units.gu(1)

            text: i18n.tr("Share with your friends")
            fontSize: "large"
            font.weight: Font.DemiBold
        }
    }

    Rectangle {
        id: topLine
        color: "#cccccc"
        height: units.dp(1)
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: postHeader.bottom
    }

    UbuntuShape {
        id: messageArea
        objectName: "messageArea"
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: postHeader.bottom
        anchors.topMargin: units.gu(1)
        anchors.leftMargin: units.gu(1)
        anchors.rightMargin: units.gu(1)

        height: units.gu(20)
        color: "#f2f2f2"

        TextArea {
            id: message
            color: "#333333"
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.bottom: parent.bottom
            anchors.margins: units.gu(1)
            textFormat: TextEdit.AutoText
            wrapMode: Text.Wrap
            width: parent.width - message.anchors.leftMargin - message.anchors.rightMargin
            clip: true
            focus: true
        }
    }

    Item {
        id: actionsBar
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: messageArea.bottom
        anchors.topMargin: units.gu(2)
        anchors.leftMargin: units.gu(1)
        anchors.rightMargin: units.gu(1)
        height: childrenRect.height

        Button {
            objectName: "cancelButton"
            anchors.left: parent.left
            text: i18n.tr("Cancel")
            color: "#cccccc"
            width: units.gu(10)
            height: units.gu(4)
            onClicked: post.visible = false;
        }

        Button {
            objectName: "postButton"
            anchors.right: parent.right
            anchors.top: parent.top
            text: i18n.tr("Post")
            color: "#dd4814"
            width: units.gu(10)
            height: units.gu(4)
            onClicked: {
                console.log(message.text);
                activitySpinner.visible = true
                friends.sendAsync(message.text);
            }
        }
    }
    
    AccountServiceModel {
        id: accounts
        serviceType: "microblogging"
    }

    ListView {
        id: accountsView
        width: parent.width
        height: childrenRect.height
        anchors {
            top: actionsBar.bottom
            topMargin: units.gu(2)
        }
        focus: true
        model: accounts
        delegate: Item {
                width: parent.width
                height: childrenRect.height
                AccountService {
                    id: accts
                    objectHandle: accountService
                    Component.onCompleted: {
                        sw.checked = accts.enabled;

                    }
                    onEnabledChanged: {
                        console.log ("ENABLED CHANGED");
                        sw.checked = accts.enabled;
                    }
                }
                ListItem.Standard {
                    text: displayName
                    icon: UbuntuShape {
                        height: units.gu(2)
                        image: Image {
                            fillMode: Image.PreserveAspectFit
                            source: "image://gicon/"+accts.provider.iconName
                        }
                    }
                    control {
                        Switch {
                            id: sw
                            checked: false
                        }
                    }
                    showDivider: false
                }
        }

        populate: Transition {
            NumberAnimation { properties: "x,y"; duration: 1000 }
        }
    }


    

    ActivityIndicator {
        id: activitySpinner
        anchors.centerIn: messageArea
        visible: false
        running: visible
    }
}
