/*
 * Copyright 2012 Canonical Ltd.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1
import Friends 0.1

Item {
    id: tile
    height: status_update_content.height
    width: parent.width
    property real detailsOpacity : 0
    property string avatar: column_8
    property string sender: column_2
    property string message: column_7
    property int likes: column_10
    property string timestring: friendsUtils.createTimeString(column_6)

    FriendsUtils {
        id: friendsUtils
    }

    UbuntuShape {
        id: avatarImage
        radius: "medium"
        height: units.dp(48)
        width: units.dp(48)
        anchors {
            left: parent.left
            top: parent.top
            leftMargin: units.gu(1)
            topMargin: units.gu(1)
        }
        image: Image {
            anchors.fill: parent
            source: Qt.resolvedUrl(avatar)
            asynchronous: true
            fillMode: Image.PreserveAspectFit
        }
    }

    Item {
        id: status_update_content
        anchors {
            left: avatarImage.right
            right: parent.right
            top: parent.top
            topMargin: units.gu(1)
            leftMargin: units.gu(1)
            bottomMargin: units.gu(1)
            rightMargin: units.gu(1)
        }
        height: childrenRect.height

        Column {
            height: childrenRect.height
            spacing: units.gu(1)
            anchors {
                left: parent.left;
                right: parent.right
                bottomMargin: units.gu(2)
            }
            Label {
                text: sender
                fontSize: "medium"
                font.bold: true
                width: parent.width
            }
            Label {
                id: label
                text: message
                wrapMode: Text.WrapAtWordBoundaryOrAnywhere
                width: parent.width - units.gu(3)
                onLinkActivated: {
                    console.log(link + " link activated");
                    Qt.openUrlExternally(link);
                }
            }
            Label {
                id: likes
                text: (likes > 0) ? likes + " " + i18n.tr("people liked this") : ""
                width: parent.width
                fontSize: "small"
                color: "gray"
            }
        }

        Row {
            anchors.right: parent.right
            anchors.rightMargin: units.gu(1)
            anchors.top: parent.top
            spacing: units.gu(1)

            Label {
                id: time
                text: timestring
                fontSize: "small"
                color: "gray"
            }

        }
    }


    states: [State {
                name: "Details"
                PropertyChanges { target: tile; detailsOpacity: 1; x: 0 }
                PropertyChanges { target: content; height: status_update_content.height + detailsWrapper.height}
                StateChangeScript { 
                    script: {
                        listView.positionViewAtIndex(listView.indexAt(parent.x, parent.y) - 1, ListView.Contain);
                    }
                }
            },
            State {
                name: "List"
                PropertyChanges { target: content; height: status_update_content.height }
                PropertyChanges { target: tile; detailsOpacity: 0; x: 0 }
            }]


    transitions: Transition {
        NumberAnimation {
            duration: 300; properties: "detailsOpacity,x,height,width"
        }
    }

    MouseArea {
        anchors.fill: status_update_content
        onClicked: {
            if (tile.state != 'Details') {
                tile.state = 'Details';
            } else {
                tile.state = 'List';
            }
        }
    }

    Rectangle {
        anchors.fill: parent
        color: "black"
        opacity: 0.1
        visible: detailsOpacity > 0 ? true : false
    }

    StatusUpdateTileDetails {
        id: detailsWrapper
        opacity: detailsOpacity
        visible:  detailsOpacity > 0 ? true : false
        anchors {
            top: status_update_content.bottom
            left: parent.left
            right: parent.right
        }
    }
}
