/*
 * Copyright 2013 Canonical Ltd.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * telephony-app is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1
import Dee 3.0

Page {
    property string stream: "messages"
    property int unseen: 0
    property string search
    property DeeListModel deeModel: _messagesModel


    Behavior on x {
        SequentialAnimation{
            PropertyAction { property: "x"; value: main.width }
            PropertyAnimation { duration: 400 }
        }
    }

    Component {
        id: statusDelegate
        StatusUpdateTile {
            id: content
            width: ListView.view.width
            height: childrenRect.height
            ListView.onAdd: SequentialAnimation {
                ScriptAction { script: {unseen = unseen + 1; console.log(column_0[0][0] + " " + column_0[0][1] + " " + column_0[0][2]) }}
            }
            ThinDivider {}
        }
    }
    
    onStreamChanged: {
        console.log("stream changed to " + stream);
    }

    onSearchChanged: {
        console.log ("onSearchChanged");
    }

    onDeeModelChanged: {
        listView.model = deeModel;
    }

    ListView {
        id: listView
        anchors.fill: parent
        snapMode: ListView.SnapToItem
        verticalLayoutDirection: ListView.BottomToTop
        cacheBuffer: parent.height

        delegate: statusDelegate
        focus: true

        addDisplaced: Transition {
            ScriptAction { script: listView.positionViewAtEnd() }
            NumberAnimation { properties: "x,y"; to: 0; duration: 1000 }
        }
        populate: Transition {
            ScriptAction { script: waitTimer.start() }
            NumberAnimation { properties: "x,y"; to: 0; duration: 1000 }
        }
    }

    Timer {
        id: waitTimer
        interval: 100
        repeat: false
        triggeredOnStart: false
        running: false
        onTriggered: { 
            listView.positionViewAtEnd();
        }
    }

    Scrollbar {
        flickableItem: listView
    }

    property ActionList tools: ToolbarActions {
        Action {
            text: i18n.tr("Top")
            onTriggered: {
                listView.positionViewAtEnd()
            }
        }
        Action {
            text: i18n.tr("Post")
            iconSource: ("images/gwibber-new-post.png")
            onTriggered: { 
                tools.active = false;
                post.visible = true;
            }
        }
        back {
            text: i18n.tr("Cancel")
            visible: true
            onTriggered: active = false;
        }
    }
}
